@@ -12,7 +12,7 @@ my $authors =
             { name => 'Dave *'  },
             { name => 'David *' },
         ],
-        all => { email => '*gmail.com' },
+        all => { email => '*cpan.org' },
     });
 
 my %output = (
